Class: Google::Apis::ClassroomV1::Announcement
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Announcement
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Announcement created by a teacher for students of the course
Instance Attribute Summary collapse
-
#alternate_link ⇒ String
Absolute link to this announcement in the Classroom web UI.
-
#assignee_mode ⇒ String
Assignee mode of the announcement.
-
#course_id ⇒ String
Identifier of the course.
-
#creation_time ⇒ String
Timestamp when this announcement was created.
-
#creator_user_id ⇒ String
Identifier for the user that created the announcement.
-
#id ⇒ String
Classroom-assigned identifier of this announcement, unique per course.
-
#individual_students_options ⇒ Google::Apis::ClassroomV1::IndividualStudentsOptions
Assignee details about a coursework/announcement.
-
#materials ⇒ Array<Google::Apis::ClassroomV1::Material>
Additional materials.
-
#scheduled_time ⇒ String
Optional timestamp when this announcement is scheduled to be published.
-
#state ⇒ String
Status of this announcement.
-
#text ⇒ String
Description of this announcement.
-
#update_time ⇒ String
Timestamp of the most recent change to this announcement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Announcement
constructor
A new instance of Announcement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Announcement
Returns a new instance of Announcement.
282 283 284 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_link ⇒ String
Absolute link to this announcement in the Classroom web UI. This is only
populated if state is PUBLISHED. Read-only.
Corresponds to the JSON property alternateLink
221 222 223 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 221 def alternate_link @alternate_link end |
#assignee_mode ⇒ String
Assignee mode of the announcement. If unspecified, the default value is
ALL_STUDENTS.
Corresponds to the JSON property assigneeMode
227 228 229 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 227 def assignee_mode @assignee_mode end |
#course_id ⇒ String
Identifier of the course. Read-only.
Corresponds to the JSON property courseId
232 233 234 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 232 def course_id @course_id end |
#creation_time ⇒ String
Timestamp when this announcement was created. Read-only.
Corresponds to the JSON property creationTime
237 238 239 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 237 def creation_time @creation_time end |
#creator_user_id ⇒ String
Identifier for the user that created the announcement. Read-only.
Corresponds to the JSON property creatorUserId
242 243 244 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 242 def creator_user_id @creator_user_id end |
#id ⇒ String
Classroom-assigned identifier of this announcement, unique per course. Read-
only.
Corresponds to the JSON property id
248 249 250 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 248 def id @id end |
#individual_students_options ⇒ Google::Apis::ClassroomV1::IndividualStudentsOptions
Assignee details about a coursework/announcement. This field is set if and
only if assigneeMode is INDIVIDUAL_STUDENTS.
Corresponds to the JSON property individualStudentsOptions
254 255 256 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 254 def @individual_students_options end |
#materials ⇒ Array<Google::Apis::ClassroomV1::Material>
Additional materials. Announcements must have no more than 20 material items.
Corresponds to the JSON property materials
259 260 261 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 259 def materials @materials end |
#scheduled_time ⇒ String
Optional timestamp when this announcement is scheduled to be published.
Corresponds to the JSON property scheduledTime
264 265 266 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 264 def scheduled_time @scheduled_time end |
#state ⇒ String
Status of this announcement. If unspecified, the default state is DRAFT.
Corresponds to the JSON property state
269 270 271 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 269 def state @state end |
#text ⇒ String
Description of this announcement. The text must be a valid UTF-8 string
containing no more than 30,000 characters.
Corresponds to the JSON property text
275 276 277 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 275 def text @text end |
#update_time ⇒ String
Timestamp of the most recent change to this announcement. Read-only.
Corresponds to the JSON property updateTime
280 281 282 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 280 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 287 def update!(**args) @alternate_link = args[:alternate_link] if args.key?(:alternate_link) @assignee_mode = args[:assignee_mode] if args.key?(:assignee_mode) @course_id = args[:course_id] if args.key?(:course_id) @creation_time = args[:creation_time] if args.key?(:creation_time) @creator_user_id = args[:creator_user_id] if args.key?(:creator_user_id) @id = args[:id] if args.key?(:id) @individual_students_options = args[:individual_students_options] if args.key?(:individual_students_options) @materials = args[:materials] if args.key?(:materials) @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time) @state = args[:state] if args.key?(:state) @text = args[:text] if args.key?(:text) @update_time = args[:update_time] if args.key?(:update_time) end |