Class: Google::Apis::ClassroomV1::AssignmentSubmission

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Student work for an assignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssignmentSubmission

Returns a new instance of AssignmentSubmission.



351
352
353
# File 'lib/google/apis/classroom_v1/classes.rb', line 351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<Google::Apis::ClassroomV1::Attachment>

Attachments added by the student. Drive files that correspond to materials with a share mode of STUDENT_COPY may not exist yet if the student has not accessed the assignment in Classroom. Some attachment metadata is only populated if the requesting user has permission to access it. Identifier and alternate_link fields are always available, but others (for example, title) may not be. Corresponds to the JSON property attachments



349
350
351
# File 'lib/google/apis/classroom_v1/classes.rb', line 349

def attachments
  @attachments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



356
357
358
# File 'lib/google/apis/classroom_v1/classes.rb', line 356

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
end