Class: Google::Apis::ClassroomV1::CourseWorkMaterial
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::CourseWorkMaterial
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Course work material created by a teacher for students of the course
Instance Attribute Summary collapse
-
#alternate_link ⇒ String
Absolute link to this course work material in the Classroom web UI.
-
#assignee_mode ⇒ String
Assignee mode of the course work material.
-
#course_id ⇒ String
Identifier of the course.
-
#creation_time ⇒ String
Timestamp when this course work material was created.
-
#creator_user_id ⇒ String
Identifier for the user that created the course work material.
-
#description ⇒ String
Optional description of this course work material.
-
#id ⇒ String
Classroom-assigned identifier of this course work material, unique per course.
-
#individual_students_options ⇒ Google::Apis::ClassroomV1::IndividualStudentsOptions
Assignee details about a coursework/announcement.
-
#materials ⇒ Array<Google::Apis::ClassroomV1::Material>
Additional materials.
-
#scheduled_time ⇒ String
Optional timestamp when this course work material is scheduled to be published.
-
#state ⇒ String
Status of this course work material.
-
#title ⇒ String
Title of this course work material.
-
#topic_id ⇒ String
Identifier for the topic that this course work material is associated with.
-
#update_time ⇒ String
Timestamp of the most recent change to this course work material.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CourseWorkMaterial
constructor
A new instance of CourseWorkMaterial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CourseWorkMaterial
Returns a new instance of CourseWorkMaterial.
1035 1036 1037 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_link ⇒ String
Absolute link to this course work material in the Classroom web UI. This is
only populated if state is PUBLISHED. Read-only.
Corresponds to the JSON property alternateLink
960 961 962 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 960 def alternate_link @alternate_link end |
#assignee_mode ⇒ String
Assignee mode of the course work material. If unspecified, the default value
is ALL_STUDENTS.
Corresponds to the JSON property assigneeMode
966 967 968 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 966 def assignee_mode @assignee_mode end |
#course_id ⇒ String
Identifier of the course. Read-only.
Corresponds to the JSON property courseId
971 972 973 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 971 def course_id @course_id end |
#creation_time ⇒ String
Timestamp when this course work material was created. Read-only.
Corresponds to the JSON property creationTime
976 977 978 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 976 def creation_time @creation_time end |
#creator_user_id ⇒ String
Identifier for the user that created the course work material. Read-only.
Corresponds to the JSON property creatorUserId
981 982 983 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 981 def creator_user_id @creator_user_id end |
#description ⇒ String
Optional description of this course work material. The text must be a valid
UTF-8 string containing no more than 30,000 characters.
Corresponds to the JSON property description
987 988 989 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 987 def description @description end |
#id ⇒ String
Classroom-assigned identifier of this course work material, unique per course.
Read-only.
Corresponds to the JSON property id
993 994 995 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 993 def id @id end |
#individual_students_options ⇒ Google::Apis::ClassroomV1::IndividualStudentsOptions
Assignee details about a coursework/announcement. This field is set if and
only if assigneeMode is INDIVIDUAL_STUDENTS.
Corresponds to the JSON property individualStudentsOptions
999 1000 1001 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 999 def @individual_students_options end |
#materials ⇒ Array<Google::Apis::ClassroomV1::Material>
Additional materials. A course work material must have no more than 20
material items.
Corresponds to the JSON property materials
1005 1006 1007 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1005 def materials @materials end |
#scheduled_time ⇒ String
Optional timestamp when this course work material is scheduled to be published.
Corresponds to the JSON property scheduledTime
1010 1011 1012 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1010 def scheduled_time @scheduled_time end |
#state ⇒ String
Status of this course work material. If unspecified, the default state is
DRAFT.
Corresponds to the JSON property state
1016 1017 1018 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1016 def state @state end |
#title ⇒ String
Title of this course work material. The title must be a valid UTF-8 string
containing between 1 and 3000 characters.
Corresponds to the JSON property title
1022 1023 1024 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1022 def title @title end |
#topic_id ⇒ String
Identifier for the topic that this course work material is associated with.
Must match an existing topic in the course.
Corresponds to the JSON property topicId
1028 1029 1030 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1028 def topic_id @topic_id end |
#update_time ⇒ String
Timestamp of the most recent change to this course work material. Read-only.
Corresponds to the JSON property updateTime
1033 1034 1035 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1033 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1040 def update!(**args) @alternate_link = args[:alternate_link] if args.key?(:alternate_link) @assignee_mode = args[:assignee_mode] if args.key?(:assignee_mode) @course_id = args[:course_id] if args.key?(:course_id) @creation_time = args[:creation_time] if args.key?(:creation_time) @creator_user_id = args[:creator_user_id] if args.key?(:creator_user_id) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @individual_students_options = args[:individual_students_options] if args.key?(:individual_students_options) @materials = args[:materials] if args.key?(:materials) @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time) @state = args[:state] if args.key?(:state) @title = args[:title] if args.key?(:title) @topic_id = args[:topic_id] if args.key?(:topic_id) @update_time = args[:update_time] if args.key?(:update_time) end |