Class: Google::Apis::ClassroomV1::EmbedUri

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

URI to be iframed after being populated with query parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EmbedUri

Returns a new instance of EmbedUri.



1181
1182
1183
# File 'lib/google/apis/classroom_v1/classes.rb', line 1181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#uriString

Required. URI to be iframed after being populated with query parameters. This must be a valid UTF-8 string containing between 1 and 1800 characters. Corresponds to the JSON property uri

Returns:

  • (String)


1179
1180
1181
# File 'lib/google/apis/classroom_v1/classes.rb', line 1179

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1186
1187
1188
# File 'lib/google/apis/classroom_v1/classes.rb', line 1186

def update!(**args)
  @uri = args[:uri] if args.key?(:uri)
end