Class: Google::Apis::ClassroomV1::Empty

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty);

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Empty

Returns a new instance of Empty.



1206
1207
1208
# File 'lib/google/apis/classroom_v1/classes.rb', line 1206

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1211
1212
# File 'lib/google/apis/classroom_v1/classes.rb', line 1211

def update!(**args)
end