Class: Google::Apis::ClassroomV1::GeminiGem
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::GeminiGem
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Gemini Gem link.
Instance Attribute Summary collapse
-
#id ⇒ String
Gems resource id.
-
#title ⇒ String
Title of the Gem.
-
#url ⇒ String
URL that can be used to access the Gem.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GeminiGem
constructor
A new instance of GeminiGem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GeminiGem
Returns a new instance of GeminiGem.
1296 1297 1298 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Gems resource id.
Corresponds to the JSON property id
1284 1285 1286 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1284 def id @id end |
#title ⇒ String
Title of the Gem.
Corresponds to the JSON property title
1289 1290 1291 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1289 def title @title end |
#url ⇒ String
URL that can be used to access the Gem.
Corresponds to the JSON property url
1294 1295 1296 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1294 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1301 1302 1303 1304 1305 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1301 def update!(**args) @id = args[:id] if args.key?(:id) @title = args[:title] if args.key?(:title) @url = args[:url] if args.key?(:url) end |