Class: Google::Apis::ClassroomV1::GradeHistory

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

The history of each grade on this submission.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GradeHistory

Returns a new instance of GradeHistory.



1432
1433
1434
# File 'lib/google/apis/classroom_v1/classes.rb', line 1432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actor_user_idString

The teacher who made the grade change. Corresponds to the JSON property actorUserId

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/classroom_v1/classes.rb', line 1410

def actor_user_id
  @actor_user_id
end

#grade_change_typeString

The type of grade change at this time in the submission grade history. Corresponds to the JSON property gradeChangeType

Returns:

  • (String)


1415
1416
1417
# File 'lib/google/apis/classroom_v1/classes.rb', line 1415

def grade_change_type
  @grade_change_type
end

#grade_timestampString

When the grade of the submission was changed. Corresponds to the JSON property gradeTimestamp

Returns:

  • (String)


1420
1421
1422
# File 'lib/google/apis/classroom_v1/classes.rb', line 1420

def grade_timestamp
  @grade_timestamp
end

#max_pointsFloat

The denominator of the grade at this time in the submission grade history. Corresponds to the JSON property maxPoints

Returns:

  • (Float)


1425
1426
1427
# File 'lib/google/apis/classroom_v1/classes.rb', line 1425

def max_points
  @max_points
end

#points_earnedFloat

The numerator of the grade at this time in the submission grade history. Corresponds to the JSON property pointsEarned

Returns:

  • (Float)


1430
1431
1432
# File 'lib/google/apis/classroom_v1/classes.rb', line 1430

def points_earned
  @points_earned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1437
1438
1439
1440
1441
1442
1443
# File 'lib/google/apis/classroom_v1/classes.rb', line 1437

def update!(**args)
  @actor_user_id = args[:actor_user_id] if args.key?(:actor_user_id)
  @grade_change_type = args[:grade_change_type] if args.key?(:grade_change_type)
  @grade_timestamp = args[:grade_timestamp] if args.key?(:grade_timestamp)
  @max_points = args[:max_points] if args.key?(:max_points)
  @points_earned = args[:points_earned] if args.key?(:points_earned)
end