Class: Google::Apis::ClassroomV1::Link
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Link
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
URL item.
Instance Attribute Summary collapse
-
#thumbnail_url ⇒ String
URL of a thumbnail image of the target URL.
-
#title ⇒ String
Title of the target of the URL.
-
#url ⇒ String
URL to link to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Link
constructor
A new instance of Link.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Link
Returns a new instance of Link.
1736 1737 1738 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#thumbnail_url ⇒ String
URL of a thumbnail image of the target URL. Read-only.
Corresponds to the JSON property thumbnailUrl
1723 1724 1725 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1723 def thumbnail_url @thumbnail_url end |
#title ⇒ String
Title of the target of the URL. Read-only.
Corresponds to the JSON property title
1728 1729 1730 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1728 def title @title end |
#url ⇒ String
URL to link to. This must be a valid UTF-8 string containing between 1 and
2024 characters.
Corresponds to the JSON property url
1734 1735 1736 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1734 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1741 1742 1743 1744 1745 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1741 def update!(**args) @thumbnail_url = args[:thumbnail_url] if args.key?(:thumbnail_url) @title = args[:title] if args.key?(:title) @url = args[:url] if args.key?(:url) end |