Class: Google::Apis::ClassroomV1::ListGuardiansResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Response when listing guardians.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGuardiansResponse

Returns a new instance of ListGuardiansResponse.



1946
1947
1948
# File 'lib/google/apis/classroom_v1/classes.rb', line 1946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guardiansArray<Google::Apis::ClassroomV1::Guardian>

Guardians on this page of results that met the criteria specified in the request. Corresponds to the JSON property guardians



1938
1939
1940
# File 'lib/google/apis/classroom_v1/classes.rb', line 1938

def guardians
  @guardians
end

#next_page_tokenString

Token identifying the next page of results to return. If empty, no further results are available. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1944
1945
1946
# File 'lib/google/apis/classroom_v1/classes.rb', line 1944

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1951
1952
1953
1954
# File 'lib/google/apis/classroom_v1/classes.rb', line 1951

def update!(**args)
  @guardians = args[:guardians] if args.key?(:guardians)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end