Class: Google::Apis::ClassroomV1::ListStudentGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::ListStudentGroupsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Response when listing student groups.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token identifying the next page of results to return.
-
#student_groups ⇒ Array<Google::Apis::ClassroomV1::StudentGroup>
The student groups.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListStudentGroupsResponse
constructor
A new instance of ListStudentGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListStudentGroupsResponse
Returns a new instance of ListStudentGroupsResponse.
2082 2083 2084 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token identifying the next page of results to return. If empty, no further
results are available.
Corresponds to the JSON property nextPageToken
2075 2076 2077 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2075 def next_page_token @next_page_token end |
#student_groups ⇒ Array<Google::Apis::ClassroomV1::StudentGroup>
The student groups.
Corresponds to the JSON property studentGroups
2080 2081 2082 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2080 def student_groups @student_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2087 2088 2089 2090 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2087 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @student_groups = args[:student_groups] if args.key?(:student_groups) end |