Class: Google::Apis::ClassroomV1::ListStudentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::ListStudentsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Response when listing students.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token identifying the next page of results to return.
-
#students ⇒ Array<Google::Apis::ClassroomV1::Student>
Students who match the list request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListStudentsResponse
constructor
A new instance of ListStudentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListStudentsResponse
Returns a new instance of ListStudentsResponse.
2134 2135 2136 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token identifying the next page of results to return. If empty, no further
results are available.
Corresponds to the JSON property nextPageToken
2127 2128 2129 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2127 def next_page_token @next_page_token end |
#students ⇒ Array<Google::Apis::ClassroomV1::Student>
Students who match the list request.
Corresponds to the JSON property students
2132 2133 2134 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2132 def students @students end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2139 2140 2141 2142 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2139 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @students = args[:students] if args.key?(:students) end |