Class: Google::Apis::ClassroomV1::Material
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Material
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Material attached to course work. When creating attachments, setting the form
, gem, or notebook field is not supported.
Instance Attribute Summary collapse
-
#drive_file ⇒ Google::Apis::ClassroomV1::SharedDriveFile
Drive file that is used as material for course work.
-
#form ⇒ Google::Apis::ClassroomV1::Form
Google Forms item.
-
#gem_prop ⇒ Google::Apis::ClassroomV1::GeminiGem
Gemini Gem link.
-
#link ⇒ Google::Apis::ClassroomV1::Link
URL item.
-
#notebook ⇒ Google::Apis::ClassroomV1::NotebookLmNotebook
NotebookLM Notebook link.
-
#youtube_video ⇒ Google::Apis::ClassroomV1::YouTubeVideo
YouTube video item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Material
constructor
A new instance of Material.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Material
Returns a new instance of Material.
2234 2235 2236 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drive_file ⇒ Google::Apis::ClassroomV1::SharedDriveFile
Drive file that is used as material for course work.
Corresponds to the JSON property driveFile
2207 2208 2209 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2207 def drive_file @drive_file end |
#form ⇒ Google::Apis::ClassroomV1::Form
Google Forms item.
Corresponds to the JSON property form
2212 2213 2214 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2212 def form @form end |
#gem_prop ⇒ Google::Apis::ClassroomV1::GeminiGem
Gemini Gem link.
Corresponds to the JSON property gem
2217 2218 2219 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2217 def gem_prop @gem_prop end |
#link ⇒ Google::Apis::ClassroomV1::Link
URL item.
Corresponds to the JSON property link
2222 2223 2224 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2222 def link @link end |
#notebook ⇒ Google::Apis::ClassroomV1::NotebookLmNotebook
NotebookLM Notebook link.
Corresponds to the JSON property notebook
2227 2228 2229 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2227 def notebook @notebook end |
#youtube_video ⇒ Google::Apis::ClassroomV1::YouTubeVideo
YouTube video item.
Corresponds to the JSON property youtubeVideo
2232 2233 2234 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2232 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2239 def update!(**args) @drive_file = args[:drive_file] if args.key?(:drive_file) @form = args[:form] if args.key?(:form) @gem_prop = args[:gem_prop] if args.key?(:gem_prop) @link = args[:link] if args.key?(:link) @notebook = args[:notebook] if args.key?(:notebook) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |