Class: Google::Apis::ClassroomV1::ModifyAttachmentsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Request to modify the attachments of a student submission.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModifyAttachmentsRequest

Returns a new instance of ModifyAttachmentsRequest.



2260
2261
2262
# File 'lib/google/apis/classroom_v1/classes.rb', line 2260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_attachmentsArray<Google::Apis::ClassroomV1::Attachment>

Attachments to add. A student submission may not have more than 20 attachments. Form attachments are not supported. Corresponds to the JSON property addAttachments



2258
2259
2260
# File 'lib/google/apis/classroom_v1/classes.rb', line 2258

def add_attachments
  @add_attachments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2265
2266
2267
# File 'lib/google/apis/classroom_v1/classes.rb', line 2265

def update!(**args)
  @add_attachments = args[:add_attachments] if args.key?(:add_attachments)
end