Class: Google::Apis::ClassroomV1::ModifyCourseWorkAssigneesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Request to modify assignee mode and options of a coursework.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModifyCourseWorkAssigneesRequest

Returns a new instance of ModifyCourseWorkAssigneesRequest.



2310
2311
2312
# File 'lib/google/apis/classroom_v1/classes.rb', line 2310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assignee_modeString

Mode of the coursework describing whether it will be assigned to all students or specified individual students. Corresponds to the JSON property assigneeMode

Returns:

  • (String)


2302
2303
2304
# File 'lib/google/apis/classroom_v1/classes.rb', line 2302

def assignee_mode
  @assignee_mode
end

#modify_individual_students_optionsGoogle::Apis::ClassroomV1::ModifyIndividualStudentsOptions

Contains fields to add or remove students from a course work or announcement where the assigneeMode is set to INDIVIDUAL_STUDENTS. Corresponds to the JSON property modifyIndividualStudentsOptions



2308
2309
2310
# File 'lib/google/apis/classroom_v1/classes.rb', line 2308

def modify_individual_students_options
  @modify_individual_students_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2315
2316
2317
2318
# File 'lib/google/apis/classroom_v1/classes.rb', line 2315

def update!(**args)
  @assignee_mode = args[:assignee_mode] if args.key?(:assignee_mode)
  @modify_individual_students_options = args[:modify_individual_students_options] if args.key?(:modify_individual_students_options)
end