Class: Google::Apis::ClassroomV1::NotebookLmNotebook
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::NotebookLmNotebook
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
NotebookLM Notebook link.
Instance Attribute Summary collapse
-
#id ⇒ String
Notebook resource id.
-
#title ⇒ String
Title of the Notebook.
-
#url ⇒ String
URL that can be used to access the Notebook.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotebookLmNotebook
constructor
A new instance of NotebookLmNotebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotebookLmNotebook
Returns a new instance of NotebookLmNotebook.
2437 2438 2439 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Notebook resource id.
Corresponds to the JSON property id
2425 2426 2427 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2425 def id @id end |
#title ⇒ String
Title of the Notebook.
Corresponds to the JSON property title
2430 2431 2432 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2430 def title @title end |
#url ⇒ String
URL that can be used to access the Notebook.
Corresponds to the JSON property url
2435 2436 2437 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2435 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2442 2443 2444 2445 2446 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2442 def update!(**args) @id = args[:id] if args.key?(:id) @title = args[:title] if args.key?(:title) @url = args[:url] if args.key?(:url) end |