Class: Google::Apis::ClassroomV1::Rubric

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

The rubric of the course work. A rubric is a scoring guide used to evaluate student work and give feedback. For further details, see Rubrics structure and known limitations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rubric

Returns a new instance of Rubric.



2539
2540
2541
# File 'lib/google/apis/classroom_v1/classes.rb', line 2539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#course_idString

Identifier of the course. Read-only. Corresponds to the JSON property courseId

Returns:

  • (String)


2502
2503
2504
# File 'lib/google/apis/classroom_v1/classes.rb', line 2502

def course_id
  @course_id
end

#course_work_idString

Identifier for the course work this corresponds to. Read-only. Corresponds to the JSON property courseWorkId

Returns:

  • (String)


2507
2508
2509
# File 'lib/google/apis/classroom_v1/classes.rb', line 2507

def course_work_id
  @course_work_id
end

#creation_timeString

Output only. Timestamp when this rubric was created. Read-only. Corresponds to the JSON property creationTime

Returns:

  • (String)


2512
2513
2514
# File 'lib/google/apis/classroom_v1/classes.rb', line 2512

def creation_time
  @creation_time
end

#criteriaArray<Google::Apis::ClassroomV1::Criterion>

List of criteria. Each criterion is a dimension on which performance is rated. Corresponds to the JSON property criteria



2517
2518
2519
# File 'lib/google/apis/classroom_v1/classes.rb', line 2517

def criteria
  @criteria
end

#idString

Classroom-assigned identifier for the rubric. This is unique among rubrics for the relevant course work. Read-only. Corresponds to the JSON property id

Returns:

  • (String)


2523
2524
2525
# File 'lib/google/apis/classroom_v1/classes.rb', line 2523

def id
  @id
end

#source_spreadsheet_idString

Input only. Immutable. Google Sheets ID of the spreadsheet. This spreadsheet must contain formatted rubric settings. See Create or reuse a rubric for an assignment. Use of this field requires the https://www.googleapis.com/auth/spreadsheets.readonly or https://www.googleapis.com/auth/spreadsheets scope. Corresponds to the JSON property sourceSpreadsheetId

Returns:

  • (String)


2532
2533
2534
# File 'lib/google/apis/classroom_v1/classes.rb', line 2532

def source_spreadsheet_id
  @source_spreadsheet_id
end

#update_timeString

Output only. Timestamp of the most recent change to this rubric. Read-only. Corresponds to the JSON property updateTime

Returns:

  • (String)


2537
2538
2539
# File 'lib/google/apis/classroom_v1/classes.rb', line 2537

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2544
2545
2546
2547
2548
2549
2550
2551
2552
# File 'lib/google/apis/classroom_v1/classes.rb', line 2544

def update!(**args)
  @course_id = args[:course_id] if args.key?(:course_id)
  @course_work_id = args[:course_work_id] if args.key?(:course_work_id)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @criteria = args[:criteria] if args.key?(:criteria)
  @id = args[:id] if args.key?(:id)
  @source_spreadsheet_id = args[:source_spreadsheet_id] if args.key?(:source_spreadsheet_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end