Class: Google::Apis::ClassroomV1::Topic

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Topic created by a teacher for the course

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Topic

Returns a new instance of Topic.



3105
3106
3107
# File 'lib/google/apis/classroom_v1/classes.rb', line 3105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#course_idString

Identifier of the course. Read-only. Corresponds to the JSON property courseId

Returns:

  • (String)


3085
3086
3087
# File 'lib/google/apis/classroom_v1/classes.rb', line 3085

def course_id
  @course_id
end

#nameString

The name of the topic, generated by the user. Leading and trailing whitespaces, if any, are trimmed. Also, multiple consecutive whitespaces are collapsed into one inside the name. The result must be a non-empty string. Topic names are case sensitive, and must be no longer than 100 characters. Corresponds to the JSON property name

Returns:

  • (String)


3093
3094
3095
# File 'lib/google/apis/classroom_v1/classes.rb', line 3093

def name
  @name
end

#topic_idString

Unique identifier for the topic. Read-only. Corresponds to the JSON property topicId

Returns:

  • (String)


3098
3099
3100
# File 'lib/google/apis/classroom_v1/classes.rb', line 3098

def topic_id
  @topic_id
end

#update_timeString

The time the topic was last updated by the system. Read-only. Corresponds to the JSON property updateTime

Returns:

  • (String)


3103
3104
3105
# File 'lib/google/apis/classroom_v1/classes.rb', line 3103

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3110
3111
3112
3113
3114
3115
# File 'lib/google/apis/classroom_v1/classes.rb', line 3110

def update!(**args)
  @course_id = args[:course_id] if args.key?(:course_id)
  @name = args[:name] if args.key?(:name)
  @topic_id = args[:topic_id] if args.key?(:topic_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end