Class: Google::Apis::ClassroomV1::UserProfile

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Global information for a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserProfile

Returns a new instance of UserProfile.



3025
3026
3027
# File 'lib/google/apis/classroom_v1/classes.rb', line 3025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_addressString

Email address of the user. Must request https://www.googleapis.com/auth/ classroom.profile.emails scope for this field to be populated in a response body. Read-only. Corresponds to the JSON property emailAddress

Returns:

  • (String)


2992
2993
2994
# File 'lib/google/apis/classroom_v1/classes.rb', line 2992

def email_address
  @email_address
end

#idString

Identifier of the user. Read-only. Corresponds to the JSON property id

Returns:

  • (String)


2997
2998
2999
# File 'lib/google/apis/classroom_v1/classes.rb', line 2997

def id
  @id
end

#nameGoogle::Apis::ClassroomV1::Name

Details of the user's name. Corresponds to the JSON property name



3002
3003
3004
# File 'lib/google/apis/classroom_v1/classes.rb', line 3002

def name
  @name
end

#permissionsArray<Google::Apis::ClassroomV1::GlobalPermission>

Global permissions of the user. Read-only. Corresponds to the JSON property permissions



3007
3008
3009
# File 'lib/google/apis/classroom_v1/classes.rb', line 3007

def permissions
  @permissions
end

#photo_urlString

URL of user's profile photo. Must request https://www.googleapis.com/auth/ classroom.profile.photos scope for this field to be populated in a response body. Read-only. Corresponds to the JSON property photoUrl

Returns:

  • (String)


3014
3015
3016
# File 'lib/google/apis/classroom_v1/classes.rb', line 3014

def photo_url
  @photo_url
end

#verified_teacherBoolean Also known as: verified_teacher?

Represents whether a Google Workspace for Education user's domain administrator has explicitly verified them as being a teacher. This field is always false if the user is not a member of a Google Workspace for Education domain. Read-only Corresponds to the JSON property verifiedTeacher

Returns:

  • (Boolean)


3022
3023
3024
# File 'lib/google/apis/classroom_v1/classes.rb', line 3022

def verified_teacher
  @verified_teacher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3030
3031
3032
3033
3034
3035
3036
3037
# File 'lib/google/apis/classroom_v1/classes.rb', line 3030

def update!(**args)
  @email_address = args[:email_address] if args.key?(:email_address)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @permissions = args[:permissions] if args.key?(:permissions)
  @photo_url = args[:photo_url] if args.key?(:photo_url)
  @verified_teacher = args[:verified_teacher] if args.key?(:verified_teacher)
end