Class: Google::Apis::ClassroomV1::YouTubeVideo
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::YouTubeVideo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
YouTube video item.
Instance Attribute Summary collapse
-
#alternate_link ⇒ String
URL that can be used to view the YouTube video.
-
#id ⇒ String
YouTube API resource ID.
-
#thumbnail_url ⇒ String
URL of a thumbnail image of the YouTube video.
-
#title ⇒ String
Title of the YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YouTubeVideo
constructor
A new instance of YouTubeVideo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YouTubeVideo
Returns a new instance of YouTubeVideo.
3210 3211 3212 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_link ⇒ String
URL that can be used to view the YouTube video. Read-only.
Corresponds to the JSON property alternateLink
3193 3194 3195 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3193 def alternate_link @alternate_link end |
#id ⇒ String
YouTube API resource ID.
Corresponds to the JSON property id
3198 3199 3200 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3198 def id @id end |
#thumbnail_url ⇒ String
URL of a thumbnail image of the YouTube video. Read-only.
Corresponds to the JSON property thumbnailUrl
3203 3204 3205 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3203 def thumbnail_url @thumbnail_url end |
#title ⇒ String
Title of the YouTube video. Read-only.
Corresponds to the JSON property title
3208 3209 3210 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3208 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3215 3216 3217 3218 3219 3220 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3215 def update!(**args) @alternate_link = args[:alternate_link] if args.key?(:alternate_link) @id = args[:id] if args.key?(:id) @thumbnail_url = args[:thumbnail_url] if args.key?(:thumbnail_url) @title = args[:title] if args.key?(:title) end |