Class: Google::Apis::ClassroomV1::AddOnAttachmentStudentSubmission
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::AddOnAttachmentStudentSubmission
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Payload for grade update requests.
Instance Attribute Summary collapse
-
#course_work_submission_id ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#points_earned ⇒ Float
Student grade on this attachment.
-
#post_submission_state ⇒ String
Submission state of add-on attachment's parent post (i.e. assignment).
-
#user_id ⇒ String
Identifier for the student that owns this submission.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddOnAttachmentStudentSubmission
constructor
A new instance of AddOnAttachmentStudentSubmission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddOnAttachmentStudentSubmission
Returns a new instance of AddOnAttachmentStudentSubmission.
161 162 163 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#course_work_submission_id ⇒ String
Output only. Identifier of the course work submission under which this
attachment submission was made.
Corresponds to the JSON property courseWorkSubmissionId
135 136 137 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 135 def course_work_submission_id @course_work_submission_id end |
#id ⇒ String
Output only. Classroom-assigned identifier for this student submission. This
is unique among submissions for the relevant course work and add-on attachment
combination.
Corresponds to the JSON property id
142 143 144 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 142 def id @id end |
#points_earned ⇒ Float
Student grade on this attachment. If unset, no grade was set.
Corresponds to the JSON property pointsEarned
147 148 149 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 147 def points_earned @points_earned end |
#post_submission_state ⇒ String
Submission state of add-on attachment's parent post (i.e. assignment).
Corresponds to the JSON property postSubmissionState
152 153 154 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 152 def post_submission_state @post_submission_state end |
#user_id ⇒ String
Identifier for the student that owns this submission. Requires the user to be
a teacher in the course and have permission to read student submissions. Read-
only.
Corresponds to the JSON property userId
159 160 161 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 159 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
166 167 168 169 170 171 172 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 166 def update!(**args) @course_work_submission_id = args[:course_work_submission_id] if args.key?(:course_work_submission_id) @id = args[:id] if args.key?(:id) @points_earned = args[:points_earned] if args.key?(:points_earned) @post_submission_state = args[:post_submission_state] if args.key?(:post_submission_state) @user_id = args[:user_id] if args.key?(:user_id) end |