Class: Google::Apis::ClassroomV1::AddOnAttachmentStudentSubmission

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Payload for grade update requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddOnAttachmentStudentSubmission

Returns a new instance of AddOnAttachmentStudentSubmission.



148
149
150
# File 'lib/google/apis/classroom_v1/classes.rb', line 148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#points_earnedFloat

Student grade on this attachment. If unset, no grade was set. Corresponds to the JSON property pointsEarned

Returns:

  • (Float)


134
135
136
# File 'lib/google/apis/classroom_v1/classes.rb', line 134

def points_earned
  @points_earned
end

#post_submission_stateString

Submission state of add-on attachment's parent post (i.e. assignment). Corresponds to the JSON property postSubmissionState

Returns:

  • (String)


139
140
141
# File 'lib/google/apis/classroom_v1/classes.rb', line 139

def post_submission_state
  @post_submission_state
end

#user_idString

Identifier for the student that owns this submission. Requires the user to be a teacher in the course and have permission to read student submissions. Read- only. Corresponds to the JSON property userId

Returns:

  • (String)


146
147
148
# File 'lib/google/apis/classroom_v1/classes.rb', line 146

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



153
154
155
156
157
# File 'lib/google/apis/classroom_v1/classes.rb', line 153

def update!(**args)
  @points_earned = args[:points_earned] if args.key?(:points_earned)
  @post_submission_state = args[:post_submission_state] if args.key?(:post_submission_state)
  @user_id = args[:user_id] if args.key?(:user_id)
end