Class: Google::Apis::ClassroomV1::Course
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Course
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
A Course in Classroom.
Instance Attribute Summary collapse
-
#alternate_link ⇒ String
Absolute link to this course in the Classroom web UI.
-
#calendar_id ⇒ String
The Calendar ID for a calendar that all course members can see, to which Classroom adds events for course work and announcements in the course.
-
#course_group_email ⇒ String
The email address of a Google group containing all members of the course.
-
#course_material_sets ⇒ Array<Google::Apis::ClassroomV1::CourseMaterialSet>
Sets of materials that appear on the "about" page of this course.
-
#course_state ⇒ String
State of the course.
-
#creation_time ⇒ String
Creation time of the course.
-
#description ⇒ String
Optional description.
-
#description_heading ⇒ String
Optional heading for the description.
-
#enrollment_code ⇒ String
Enrollment code to use when joining this course.
-
#gradebook_settings ⇒ Google::Apis::ClassroomV1::GradebookSettings
The gradebook settings for a course.
-
#guardians_enabled ⇒ Boolean
(also: #guardians_enabled?)
Whether or not guardian notifications are enabled for this course.
-
#id ⇒ String
Identifier for this course assigned by Classroom.
-
#levels ⇒ String
Optional.
-
#name ⇒ String
Name of the course.
-
#owner_id ⇒ String
The identifier of the owner of a course.
-
#room ⇒ String
Optional room location.
-
#section ⇒ String
Section of the course.
-
#subject ⇒ String
Optional.
-
#teacher_folder ⇒ Google::Apis::ClassroomV1::DriveFolder
Representation of a Google Drive folder.
-
#teacher_group_email ⇒ String
The email address of a Google group containing all teachers of the course.
-
#update_time ⇒ String
Time of the most recent update to this course.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Course
constructor
A new instance of Course.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Course
Returns a new instance of Course.
601 602 603 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 601 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_link ⇒ String
Absolute link to this course in the Classroom web UI. Read-only.
Corresponds to the JSON property alternateLink
466 467 468 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 466 def alternate_link @alternate_link end |
#calendar_id ⇒ String
The Calendar ID for a calendar that all course members can see, to which
Classroom adds events for course work and announcements in the course. The
Calendar for a course is created asynchronously when the course is set to
CourseState.ACTIVE for the first time (at creation time or when it is updated
to ACTIVE through the UI or the API). The Calendar ID will not be populated
until the creation process is completed. Read-only.
Corresponds to the JSON property calendarId
476 477 478 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 476 def calendar_id @calendar_id end |
#course_group_email ⇒ String
The email address of a Google group containing all members of the course. This
group does not accept email and can only be used for permissions. Read-only.
Corresponds to the JSON property courseGroupEmail
482 483 484 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 482 def course_group_email @course_group_email end |
#course_material_sets ⇒ Array<Google::Apis::ClassroomV1::CourseMaterialSet>
Sets of materials that appear on the "about" page of this course. Read-only.
Corresponds to the JSON property courseMaterialSets
487 488 489 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 487 def course_material_sets @course_material_sets end |
#course_state ⇒ String
State of the course. If unspecified, the default state is PROVISIONED.
Corresponds to the JSON property courseState
492 493 494 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 492 def course_state @course_state end |
#creation_time ⇒ String
Creation time of the course. Specifying this field in a course update mask
results in an error. Read-only.
Corresponds to the JSON property creationTime
498 499 500 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 498 def creation_time @creation_time end |
#description ⇒ String
Optional description. For example, "We'll be learning about the structure of
living creatures from a combination of textbooks, guest lectures, and lab work.
Expect to be excited!" If set, this field must be a valid UTF-8 string and no
longer than 30,000 characters.
Corresponds to the JSON property description
506 507 508 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 506 def description @description end |
#description_heading ⇒ String
Optional heading for the description. For example, "Welcome to 10th Grade
Biology." If set, this field must be a valid UTF-8 string and no longer than
3600 characters.
Corresponds to the JSON property descriptionHeading
513 514 515 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 513 def description_heading @description_heading end |
#enrollment_code ⇒ String
Enrollment code to use when joining this course. Specifying this field in a
course update mask results in an error. Read-only.
Corresponds to the JSON property enrollmentCode
519 520 521 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 519 def enrollment_code @enrollment_code end |
#gradebook_settings ⇒ Google::Apis::ClassroomV1::GradebookSettings
The gradebook settings for a course. See the help center article for details.
Corresponds to the JSON property gradebookSettings
525 526 527 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 525 def gradebook_settings @gradebook_settings end |
#guardians_enabled ⇒ Boolean Also known as: guardians_enabled?
Whether or not guardian notifications are enabled for this course. Read-only.
Corresponds to the JSON property guardiansEnabled
530 531 532 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 530 def guardians_enabled @guardians_enabled end |
#id ⇒ String
Identifier for this course assigned by Classroom. When creating a course, you
may optionally set this identifier to an alias string in the request to create
a corresponding alias. The id is still assigned by Classroom and cannot be
updated after the course is created. Specifying this field in a course update
mask results in an error.
Corresponds to the JSON property id
540 541 542 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 540 def id @id end |
#levels ⇒ String
Optional. Levels for the course. Examples: "9th grade", "Middle school", "4th -
5th", "K-2", "3000". If set, this field must be a valid UTF-8 string and
fewer than 1000 characters. This field can only be cleared using the
PatchCourse method.
Corresponds to the JSON property levels
548 549 550 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 548 def levels @levels end |
#name ⇒ String
Name of the course. For example, "10th Grade Biology". The name is required.
It must be between 1 and 750 characters and a valid UTF-8 string.
Corresponds to the JSON property name
554 555 556 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 554 def name @name end |
#owner_id ⇒ String
The identifier of the owner of a course. When specified as a parameter of a
create course request, this field is required. The identifier can be one of
the following: * the numeric identifier for the user * the email address of
the user * the string literal "me", indicating the requesting user This must
be set in a create request. Admins can also specify this field in a patch
course request to transfer ownership. In other contexts, it is read-only.
Corresponds to the JSON property ownerId
564 565 566 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 564 def owner_id @owner_id end |
#room ⇒ String
Optional room location. For example, "301". If set, this field must be a valid
UTF-8 string and no longer than 650 characters.
Corresponds to the JSON property room
570 571 572 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 570 def room @room end |
#section ⇒ String
Section of the course. For example, "Period 2". If set, this field must be a
valid UTF-8 string and no longer than 2800 characters.
Corresponds to the JSON property section
576 577 578 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 576 def section @section end |
#subject ⇒ String
Optional. The subject of the course.
Corresponds to the JSON property subject
581 582 583 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 581 def subject @subject end |
#teacher_folder ⇒ Google::Apis::ClassroomV1::DriveFolder
Representation of a Google Drive folder.
Corresponds to the JSON property teacherFolder
586 587 588 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 586 def teacher_folder @teacher_folder end |
#teacher_group_email ⇒ String
The email address of a Google group containing all teachers of the course.
This group does not accept email and can only be used for permissions. Read-
only.
Corresponds to the JSON property teacherGroupEmail
593 594 595 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 593 def teacher_group_email @teacher_group_email end |
#update_time ⇒ String
Time of the most recent update to this course. Specifying this field in a
course update mask results in an error. Read-only.
Corresponds to the JSON property updateTime
599 600 601 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 599 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 606 def update!(**args) @alternate_link = args[:alternate_link] if args.key?(:alternate_link) @calendar_id = args[:calendar_id] if args.key?(:calendar_id) @course_group_email = args[:course_group_email] if args.key?(:course_group_email) @course_material_sets = args[:course_material_sets] if args.key?(:course_material_sets) @course_state = args[:course_state] if args.key?(:course_state) @creation_time = args[:creation_time] if args.key?(:creation_time) @description = args[:description] if args.key?(:description) @description_heading = args[:description_heading] if args.key?(:description_heading) @enrollment_code = args[:enrollment_code] if args.key?(:enrollment_code) @gradebook_settings = args[:gradebook_settings] if args.key?(:gradebook_settings) @guardians_enabled = args[:guardians_enabled] if args.key?(:guardians_enabled) @id = args[:id] if args.key?(:id) @levels = args[:levels] if args.key?(:levels) @name = args[:name] if args.key?(:name) @owner_id = args[:owner_id] if args.key?(:owner_id) @room = args[:room] if args.key?(:room) @section = args[:section] if args.key?(:section) @subject = args[:subject] if args.key?(:subject) @teacher_folder = args[:teacher_folder] if args.key?(:teacher_folder) @teacher_group_email = args[:teacher_group_email] if args.key?(:teacher_group_email) @update_time = args[:update_time] if args.key?(:update_time) end |