Class: Google::Apis::ClassroomV1::CourseWorkMaterial
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::CourseWorkMaterial
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Course work material created by a teacher for students of the course
Instance Attribute Summary collapse
-
#alternate_link ⇒ String
Absolute link to this course work material in the Classroom web UI.
-
#assignee_mode ⇒ String
Assignee mode of the course work material.
-
#course_id ⇒ String
Identifier of the course.
-
#creation_time ⇒ String
Timestamp when this course work material was created.
-
#creator_user_id ⇒ String
Identifier for the user that created the course work material.
-
#description ⇒ String
Optional description of this course work material.
-
#id ⇒ String
Classroom-assigned identifier of this course work material, unique per course.
-
#individual_students_options ⇒ Google::Apis::ClassroomV1::IndividualStudentsOptions
Assignee details about a coursework/announcement.
-
#materials ⇒ Array<Google::Apis::ClassroomV1::Material>
Additional materials.
-
#scheduled_time ⇒ String
Optional timestamp when this course work material is scheduled to be published.
-
#state ⇒ String
Status of this course work material.
-
#title ⇒ String
Title of this course work material.
-
#topic_id ⇒ String
Identifier for the topic that this course work material is associated with.
-
#update_time ⇒ String
Timestamp of the most recent change to this course work material.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CourseWorkMaterial
constructor
A new instance of CourseWorkMaterial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CourseWorkMaterial
Returns a new instance of CourseWorkMaterial.
1001 1002 1003 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_link ⇒ String
Absolute link to this course work material in the Classroom web UI. This is
only populated if state is PUBLISHED. Read-only.
Corresponds to the JSON property alternateLink
926 927 928 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 926 def alternate_link @alternate_link end |
#assignee_mode ⇒ String
Assignee mode of the course work material. If unspecified, the default value
is ALL_STUDENTS.
Corresponds to the JSON property assigneeMode
932 933 934 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 932 def assignee_mode @assignee_mode end |
#course_id ⇒ String
Identifier of the course. Read-only.
Corresponds to the JSON property courseId
937 938 939 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 937 def course_id @course_id end |
#creation_time ⇒ String
Timestamp when this course work material was created. Read-only.
Corresponds to the JSON property creationTime
942 943 944 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 942 def creation_time @creation_time end |
#creator_user_id ⇒ String
Identifier for the user that created the course work material. Read-only.
Corresponds to the JSON property creatorUserId
947 948 949 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 947 def creator_user_id @creator_user_id end |
#description ⇒ String
Optional description of this course work material. The text must be a valid
UTF-8 string containing no more than 30,000 characters.
Corresponds to the JSON property description
953 954 955 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 953 def description @description end |
#id ⇒ String
Classroom-assigned identifier of this course work material, unique per course.
Read-only.
Corresponds to the JSON property id
959 960 961 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 959 def id @id end |
#individual_students_options ⇒ Google::Apis::ClassroomV1::IndividualStudentsOptions
Assignee details about a coursework/announcement. This field is set if and
only if assigneeMode is INDIVIDUAL_STUDENTS.
Corresponds to the JSON property individualStudentsOptions
965 966 967 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 965 def @individual_students_options end |
#materials ⇒ Array<Google::Apis::ClassroomV1::Material>
Additional materials. A course work material must have no more than 20
material items.
Corresponds to the JSON property materials
971 972 973 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 971 def materials @materials end |
#scheduled_time ⇒ String
Optional timestamp when this course work material is scheduled to be published.
Corresponds to the JSON property scheduledTime
976 977 978 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 976 def scheduled_time @scheduled_time end |
#state ⇒ String
Status of this course work material. If unspecified, the default state is
DRAFT.
Corresponds to the JSON property state
982 983 984 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 982 def state @state end |
#title ⇒ String
Title of this course work material. The title must be a valid UTF-8 string
containing between 1 and 3000 characters.
Corresponds to the JSON property title
988 989 990 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 988 def title @title end |
#topic_id ⇒ String
Identifier for the topic that this course work material is associated with.
Must match an existing topic in the course.
Corresponds to the JSON property topicId
994 995 996 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 994 def topic_id @topic_id end |
#update_time ⇒ String
Timestamp of the most recent change to this course work material. Read-only.
Corresponds to the JSON property updateTime
999 1000 1001 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 999 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1006 def update!(**args) @alternate_link = args[:alternate_link] if args.key?(:alternate_link) @assignee_mode = args[:assignee_mode] if args.key?(:assignee_mode) @course_id = args[:course_id] if args.key?(:course_id) @creation_time = args[:creation_time] if args.key?(:creation_time) @creator_user_id = args[:creator_user_id] if args.key?(:creator_user_id) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @individual_students_options = args[:individual_students_options] if args.key?(:individual_students_options) @materials = args[:materials] if args.key?(:materials) @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time) @state = args[:state] if args.key?(:state) @title = args[:title] if args.key?(:title) @topic_id = args[:topic_id] if args.key?(:topic_id) @update_time = args[:update_time] if args.key?(:update_time) end |