Class: Google::Apis::ClassroomV1::GradeCategory

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Details for a grade category in a course. Coursework may have zero or one grade category, and the category may be used in computing the overall grade. See the help center article for details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GradeCategory

Returns a new instance of GradeCategory.



1366
1367
1368
# File 'lib/google/apis/classroom_v1/classes.rb', line 1366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_grade_denominatorFixnum

Default value of denominator. Only applicable when grade calculation type is TOTAL_POINTS. Corresponds to the JSON property defaultGradeDenominator

Returns:

  • (Fixnum)


1346
1347
1348
# File 'lib/google/apis/classroom_v1/classes.rb', line 1346

def default_grade_denominator
  @default_grade_denominator
end

#idString

ID of the grade category. Corresponds to the JSON property id

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/classroom_v1/classes.rb', line 1351

def id
  @id
end

#nameString

Name of the grade category. Corresponds to the JSON property name

Returns:

  • (String)


1356
1357
1358
# File 'lib/google/apis/classroom_v1/classes.rb', line 1356

def name
  @name
end

#weightFixnum

The weight of the category average as part of overall average. A weight of 12. 34% is represented as 123400 (100% is 1,000,000). The last two digits should always be zero since we use two decimal precision. Only applicable when grade calculation type is WEIGHTED_CATEGORIES. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


1364
1365
1366
# File 'lib/google/apis/classroom_v1/classes.rb', line 1364

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1371
1372
1373
1374
1375
1376
# File 'lib/google/apis/classroom_v1/classes.rb', line 1371

def update!(**args)
  @default_grade_denominator = args[:default_grade_denominator] if args.key?(:default_grade_denominator)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @weight = args[:weight] if args.key?(:weight)
end