Class: Google::Apis::ClassroomV1::GradeHistory
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::GradeHistory
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
The history of each grade on this submission.
Instance Attribute Summary collapse
-
#actor_user_id ⇒ String
The teacher who made the grade change.
-
#grade_change_type ⇒ String
The type of grade change at this time in the submission grade history.
-
#grade_timestamp ⇒ String
When the grade of the submission was changed.
-
#max_points ⇒ Float
The denominator of the grade at this time in the submission grade history.
-
#points_earned ⇒ Float
The numerator of the grade at this time in the submission grade history.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GradeHistory
constructor
A new instance of GradeHistory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GradeHistory
Returns a new instance of GradeHistory.
1400 1401 1402 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actor_user_id ⇒ String
The teacher who made the grade change.
Corresponds to the JSON property actorUserId
1378 1379 1380 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1378 def actor_user_id @actor_user_id end |
#grade_change_type ⇒ String
The type of grade change at this time in the submission grade history.
Corresponds to the JSON property gradeChangeType
1383 1384 1385 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1383 def grade_change_type @grade_change_type end |
#grade_timestamp ⇒ String
When the grade of the submission was changed.
Corresponds to the JSON property gradeTimestamp
1388 1389 1390 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1388 def @grade_timestamp end |
#max_points ⇒ Float
The denominator of the grade at this time in the submission grade history.
Corresponds to the JSON property maxPoints
1393 1394 1395 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1393 def max_points @max_points end |
#points_earned ⇒ Float
The numerator of the grade at this time in the submission grade history.
Corresponds to the JSON property pointsEarned
1398 1399 1400 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1398 def points_earned @points_earned end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1405 def update!(**args) @actor_user_id = args[:actor_user_id] if args.key?(:actor_user_id) @grade_change_type = args[:grade_change_type] if args.key?(:grade_change_type) @grade_timestamp = args[:grade_timestamp] if args.key?(:grade_timestamp) @max_points = args[:max_points] if args.key?(:max_points) @points_earned = args[:points_earned] if args.key?(:points_earned) end |