Class: Google::Apis::ClassroomV1::GradingPeriodSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Grading period settings that include all the individual grading periods in a course.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GradingPeriodSettings

Returns a new instance of GradingPeriodSettings.



1522
1523
1524
# File 'lib/google/apis/classroom_v1/classes.rb', line 1522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_to_existing_courseworkBoolean Also known as: apply_to_existing_coursework?

Supports toggling the application of grading periods on existing stream items. Once set, this value is persisted meaning that it does not need to be set in every request to update GradingPeriodSettings. If not previously set, the default is False. Corresponds to the JSON property applyToExistingCoursework

Returns:

  • (Boolean)


1512
1513
1514
# File 'lib/google/apis/classroom_v1/classes.rb', line 1512

def apply_to_existing_coursework
  @apply_to_existing_coursework
end

#grading_periodsArray<Google::Apis::ClassroomV1::GradingPeriod>

The list of grading periods in a specific course. Grading periods must not have overlapping date ranges and must be listed in chronological order. Each grading period must have a unique title within a course. Corresponds to the JSON property gradingPeriods



1520
1521
1522
# File 'lib/google/apis/classroom_v1/classes.rb', line 1520

def grading_periods
  @grading_periods
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1527
1528
1529
1530
# File 'lib/google/apis/classroom_v1/classes.rb', line 1527

def update!(**args)
  @apply_to_existing_coursework = args[:apply_to_existing_coursework] if args.key?(:apply_to_existing_coursework)
  @grading_periods = args[:grading_periods] if args.key?(:grading_periods)
end