Class: Google::Apis::ClassroomV1::Level

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

A level of the criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Level

Returns a new instance of Level.



1735
1736
1737
# File 'lib/google/apis/classroom_v1/classes.rb', line 1735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the level. Corresponds to the JSON property description

Returns:

  • (String)


1716
1717
1718
# File 'lib/google/apis/classroom_v1/classes.rb', line 1716

def description
  @description
end

#idString

The level ID. On creation, an ID is assigned. Corresponds to the JSON property id

Returns:

  • (String)


1721
1722
1723
# File 'lib/google/apis/classroom_v1/classes.rb', line 1721

def id
  @id
end

#pointsFloat

Optional points associated with this level. If set, all levels within the rubric must specify points and the value must be distinct across all levels within a single criterion. 0 is distinct from no points. Corresponds to the JSON property points

Returns:

  • (Float)


1728
1729
1730
# File 'lib/google/apis/classroom_v1/classes.rb', line 1728

def points
  @points
end

#titleString

The title of the level. If the level has no points set, title must be set. Corresponds to the JSON property title

Returns:

  • (String)


1733
1734
1735
# File 'lib/google/apis/classroom_v1/classes.rb', line 1733

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1740
1741
1742
1743
1744
1745
# File 'lib/google/apis/classroom_v1/classes.rb', line 1740

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @points = args[:points] if args.key?(:points)
  @title = args[:title] if args.key?(:title)
end