Class: Google::Apis::ClassroomV1::Level
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Level
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
A level of the criterion.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the level.
-
#id ⇒ String
The level ID.
-
#points ⇒ Float
Optional points associated with this level.
-
#title ⇒ String
The title of the level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Level
constructor
A new instance of Level.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Level
Returns a new instance of Level.
1703 1704 1705 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the level.
Corresponds to the JSON property description
1684 1685 1686 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1684 def description @description end |
#id ⇒ String
The level ID. On creation, an ID is assigned.
Corresponds to the JSON property id
1689 1690 1691 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1689 def id @id end |
#points ⇒ Float
Optional points associated with this level. If set, all levels within the
rubric must specify points and the value must be distinct across all levels
within a single criterion. 0 is distinct from no points.
Corresponds to the JSON property points
1696 1697 1698 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1696 def points @points end |
#title ⇒ String
The title of the level. If the level has no points set, title must be set.
Corresponds to the JSON property title
1701 1702 1703 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1701 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1708 1709 1710 1711 1712 1713 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 1708 def update!(**args) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @points = args[:points] if args.key?(:points) @title = args[:title] if args.key?(:title) end |