Class: Google::Apis::ClassroomV1::ListStudentGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::ListStudentGroupsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Response when listing student groups.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token identifying the next page of results to return.
-
#student_groups ⇒ Array<Google::Apis::ClassroomV1::StudentGroup>
The student groups.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListStudentGroupsResponse
constructor
A new instance of ListStudentGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListStudentGroupsResponse
Returns a new instance of ListStudentGroupsResponse.
2058 2059 2060 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token identifying the next page of results to return. If empty, no further
results are available.
Corresponds to the JSON property nextPageToken
2051 2052 2053 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2051 def next_page_token @next_page_token end |
#student_groups ⇒ Array<Google::Apis::ClassroomV1::StudentGroup>
The student groups.
Corresponds to the JSON property studentGroups
2056 2057 2058 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2056 def student_groups @student_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2063 2064 2065 2066 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2063 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @student_groups = args[:student_groups] if args.key?(:student_groups) end |