Class: Google::Apis::ClassroomV1::Material
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Material
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Material attached to course work. When creating attachments, setting the form
, gem, or notebook field is not supported.
Instance Attribute Summary collapse
-
#drive_file ⇒ Google::Apis::ClassroomV1::SharedDriveFile
Drive file that is used as material for course work.
-
#form ⇒ Google::Apis::ClassroomV1::Form
Google Forms item.
-
#gem_prop ⇒ Google::Apis::ClassroomV1::GeminiGem
Gemini Gem link.
-
#link ⇒ Google::Apis::ClassroomV1::Link
URL item.
-
#notebook ⇒ Google::Apis::ClassroomV1::NotebookLmNotebook
NotebookLM Notebook link.
-
#youtube_video ⇒ Google::Apis::ClassroomV1::YouTubeVideo
YouTube video item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Material
constructor
A new instance of Material.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Material
Returns a new instance of Material.
2232 2233 2234 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2232 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drive_file ⇒ Google::Apis::ClassroomV1::SharedDriveFile
Drive file that is used as material for course work.
Corresponds to the JSON property driveFile
2205 2206 2207 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2205 def drive_file @drive_file end |
#form ⇒ Google::Apis::ClassroomV1::Form
Google Forms item.
Corresponds to the JSON property form
2210 2211 2212 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2210 def form @form end |
#gem_prop ⇒ Google::Apis::ClassroomV1::GeminiGem
Gemini Gem link.
Corresponds to the JSON property gem
2215 2216 2217 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2215 def gem_prop @gem_prop end |
#link ⇒ Google::Apis::ClassroomV1::Link
URL item.
Corresponds to the JSON property link
2220 2221 2222 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2220 def link @link end |
#notebook ⇒ Google::Apis::ClassroomV1::NotebookLmNotebook
NotebookLM Notebook link.
Corresponds to the JSON property notebook
2225 2226 2227 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2225 def notebook @notebook end |
#youtube_video ⇒ Google::Apis::ClassroomV1::YouTubeVideo
YouTube video item.
Corresponds to the JSON property youtubeVideo
2230 2231 2232 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2230 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2237 2238 2239 2240 2241 2242 2243 2244 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2237 def update!(**args) @drive_file = args[:drive_file] if args.key?(:drive_file) @form = args[:form] if args.key?(:form) @gem_prop = args[:gem_prop] if args.key?(:gem_prop) @link = args[:link] if args.key?(:link) @notebook = args[:notebook] if args.key?(:notebook) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |