Class: Google::Apis::ClassroomV1::Rubric
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Rubric
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
The rubric of the course work. A rubric is a scoring guide used to evaluate student work and give feedback. For further details, see Rubrics structure and known limitations.
Instance Attribute Summary collapse
-
#course_id ⇒ String
Identifier of the course.
-
#course_work_id ⇒ String
Identifier for the course work this corresponds to.
-
#creation_time ⇒ String
Output only.
-
#criteria ⇒ Array<Google::Apis::ClassroomV1::Criterion>
List of criteria.
-
#id ⇒ String
Classroom-assigned identifier for the rubric.
-
#source_spreadsheet_id ⇒ String
Input only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rubric
constructor
A new instance of Rubric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rubric
Returns a new instance of Rubric.
2479 2480 2481 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#course_id ⇒ String
Identifier of the course. Read-only.
Corresponds to the JSON property courseId
2442 2443 2444 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2442 def course_id @course_id end |
#course_work_id ⇒ String
Identifier for the course work this corresponds to. Read-only.
Corresponds to the JSON property courseWorkId
2447 2448 2449 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2447 def course_work_id @course_work_id end |
#creation_time ⇒ String
Output only. Timestamp when this rubric was created. Read-only.
Corresponds to the JSON property creationTime
2452 2453 2454 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2452 def creation_time @creation_time end |
#criteria ⇒ Array<Google::Apis::ClassroomV1::Criterion>
List of criteria. Each criterion is a dimension on which performance is rated.
Corresponds to the JSON property criteria
2457 2458 2459 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2457 def criteria @criteria end |
#id ⇒ String
Classroom-assigned identifier for the rubric. This is unique among rubrics for
the relevant course work. Read-only.
Corresponds to the JSON property id
2463 2464 2465 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2463 def id @id end |
#source_spreadsheet_id ⇒ String
Input only. Immutable. Google Sheets ID of the spreadsheet. This spreadsheet
must contain formatted rubric settings. See Create or reuse a rubric for an
assignment. Use of
this field requires the https://www.googleapis.com/auth/spreadsheets.readonly
or https://www.googleapis.com/auth/spreadsheets scope.
Corresponds to the JSON property sourceSpreadsheetId
2472 2473 2474 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2472 def source_spreadsheet_id @source_spreadsheet_id end |
#update_time ⇒ String
Output only. Timestamp of the most recent change to this rubric. Read-only.
Corresponds to the JSON property updateTime
2477 2478 2479 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2477 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2484 2485 2486 2487 2488 2489 2490 2491 2492 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2484 def update!(**args) @course_id = args[:course_id] if args.key?(:course_id) @course_work_id = args[:course_work_id] if args.key?(:course_work_id) @creation_time = args[:creation_time] if args.key?(:creation_time) @criteria = args[:criteria] if args.key?(:criteria) @id = args[:id] if args.key?(:id) @source_spreadsheet_id = args[:source_spreadsheet_id] if args.key?(:source_spreadsheet_id) @update_time = args[:update_time] if args.key?(:update_time) end |