Class: Google::Apis::ClassroomV1::RubricGrade

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

A rubric grade set for the student submission. There is at most one entry per rubric criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RubricGrade

Returns a new instance of RubricGrade.



2518
2519
2520
# File 'lib/google/apis/classroom_v1/classes.rb', line 2518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#criterion_idString

Optional. Criterion ID. Corresponds to the JSON property criterionId

Returns:

  • (String)


2503
2504
2505
# File 'lib/google/apis/classroom_v1/classes.rb', line 2503

def criterion_id
  @criterion_id
end

#level_idString

Optional. Optional level ID of the selected level. If empty, no level was selected. Corresponds to the JSON property levelId

Returns:

  • (String)


2509
2510
2511
# File 'lib/google/apis/classroom_v1/classes.rb', line 2509

def level_id
  @level_id
end

#pointsFloat

Optional. Optional points assigned for this criterion, typically based on the level. Levels might or might not have points. If unset, no points were set for this criterion. Corresponds to the JSON property points

Returns:

  • (Float)


2516
2517
2518
# File 'lib/google/apis/classroom_v1/classes.rb', line 2516

def points
  @points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2523
2524
2525
2526
2527
# File 'lib/google/apis/classroom_v1/classes.rb', line 2523

def update!(**args)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @level_id = args[:level_id] if args.key?(:level_id)
  @points = args[:points] if args.key?(:points)
end