Class: Google::Apis::ClassroomV1::StudentContext
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::StudentContext
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Role-specific context if the requesting user is a student.
Instance Attribute Summary collapse
-
#submission_id ⇒ String
Requesting user's submission id to be used for grade passback and to identify the student when showing student work to the teacher.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StudentContext
constructor
A new instance of StudentContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StudentContext
Returns a new instance of StudentContext.
2740 2741 2742 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#submission_id ⇒ String
Requesting user's submission id to be used for grade passback and to identify
the student when showing student work to the teacher. This is set exactly when
supportsStudentWork is true.
Corresponds to the JSON property submissionId
2738 2739 2740 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2738 def submission_id @submission_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2745 2746 2747 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2745 def update!(**args) @submission_id = args[:submission_id] if args.key?(:submission_id) end |