Class: Google::Apis::ClassroomV1::StudentContext
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::StudentContext
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Role-specific context if the requesting user is a student.
Instance Attribute Summary collapse
-
#submission_id ⇒ String
Requesting user's submission id to be used for grade passback and to identify the student when showing student work to the teacher.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StudentContext
constructor
A new instance of StudentContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StudentContext
Returns a new instance of StudentContext.
2716 2717 2718 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#submission_id ⇒ String
Requesting user's submission id to be used for grade passback and to identify
the student when showing student work to the teacher. This is set exactly when
supportsStudentWork is true.
Corresponds to the JSON property submissionId
2714 2715 2716 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2714 def submission_id @submission_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2721 2722 2723 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2721 def update!(**args) @submission_id = args[:submission_id] if args.key?(:submission_id) end |