Class: Google::Apis::ClassroomV1::StudentSubmission
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::StudentSubmission
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Student submission for course work. StudentSubmission items are generated
when a CourseWork item is created. Student submissions that have never been
accessed (i.e. with state = NEW) may not have a creation time or update time.
Instance Attribute Summary collapse
-
#alternate_link ⇒ String
Absolute link to the submission in the Classroom web UI.
-
#assigned_grade ⇒ Float
Optional grade.
-
#assigned_rubric_grades ⇒ Hash<String,Google::Apis::ClassroomV1::RubricGrade>
Assigned rubric grades based on the rubric's Criteria.
-
#assignment_submission ⇒ Google::Apis::ClassroomV1::AssignmentSubmission
Student work for an assignment.
-
#associated_with_developer ⇒ Boolean
(also: #associated_with_developer?)
Whether this student submission is associated with the Developer Console project making the request.
-
#course_id ⇒ String
Identifier of the course.
-
#course_work_id ⇒ String
Identifier for the course work this corresponds to.
-
#course_work_type ⇒ String
Type of course work this submission is for.
-
#creation_time ⇒ String
Creation time of this submission.
-
#draft_grade ⇒ Float
Optional pending grade.
-
#draft_rubric_grades ⇒ Hash<String,Google::Apis::ClassroomV1::RubricGrade>
Pending rubric grades based on the rubric's criteria.
-
#id ⇒ String
Classroom-assigned Identifier for the student submission.
-
#late ⇒ Boolean
(also: #late?)
Whether this submission is late.
-
#multiple_choice_submission ⇒ Google::Apis::ClassroomV1::MultipleChoiceSubmission
Student work for a multiple-choice question.
-
#short_answer_submission ⇒ Google::Apis::ClassroomV1::ShortAnswerSubmission
Student work for a short answer question.
-
#state ⇒ String
State of this submission.
-
#submission_history ⇒ Array<Google::Apis::ClassroomV1::SubmissionHistory>
The history of the submission (includes state and grade histories).
-
#update_time ⇒ String
Last update time of this submission.
-
#user_id ⇒ String
Identifier for the student that owns this submission.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StudentSubmission
constructor
A new instance of StudentSubmission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StudentSubmission
Returns a new instance of StudentSubmission.
2784 2785 2786 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_link ⇒ String
Absolute link to the submission in the Classroom web UI. Read-only.
Corresponds to the JSON property alternateLink
2675 2676 2677 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2675 def alternate_link @alternate_link end |
#assigned_grade ⇒ Float
Optional grade. If unset, no grade was set. This value must be non-negative.
Decimal (that is, non-integer) values are allowed, but are rounded to two
decimal places. This may be modified only by course teachers.
Corresponds to the JSON property assignedGrade
2682 2683 2684 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2682 def assigned_grade @assigned_grade end |
#assigned_rubric_grades ⇒ Hash<String,Google::Apis::ClassroomV1::RubricGrade>
Assigned rubric grades based on the rubric's Criteria. This map is empty if
there is no rubric attached to this course work or if a rubric is attached,
but no grades have been set on any Criteria. Entries are only populated for
grades that have been set. Key: The rubric's criterion ID. Read-only.
Corresponds to the JSON property assignedRubricGrades
2690 2691 2692 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2690 def assigned_rubric_grades @assigned_rubric_grades end |
#assignment_submission ⇒ Google::Apis::ClassroomV1::AssignmentSubmission
Student work for an assignment.
Corresponds to the JSON property assignmentSubmission
2695 2696 2697 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2695 def assignment_submission @assignment_submission end |
#associated_with_developer ⇒ Boolean Also known as: associated_with_developer?
Whether this student submission is associated with the Developer Console
project making the request. See CreateCourseWork for more details. Read-only.
Corresponds to the JSON property associatedWithDeveloper
2701 2702 2703 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2701 def associated_with_developer @associated_with_developer end |
#course_id ⇒ String
Identifier of the course. Read-only.
Corresponds to the JSON property courseId
2707 2708 2709 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2707 def course_id @course_id end |
#course_work_id ⇒ String
Identifier for the course work this corresponds to. Read-only.
Corresponds to the JSON property courseWorkId
2712 2713 2714 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2712 def course_work_id @course_work_id end |
#course_work_type ⇒ String
Type of course work this submission is for. Read-only.
Corresponds to the JSON property courseWorkType
2717 2718 2719 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2717 def course_work_type @course_work_type end |
#creation_time ⇒ String
Creation time of this submission. This may be unset if the student has not
accessed this item. Read-only.
Corresponds to the JSON property creationTime
2723 2724 2725 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2723 def creation_time @creation_time end |
#draft_grade ⇒ Float
Optional pending grade. If unset, no grade was set. This value must be non-
negative. Decimal (that is, non-integer) values are allowed, but are rounded
to two decimal places. This is only visible to and modifiable by course
teachers.
Corresponds to the JSON property draftGrade
2731 2732 2733 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2731 def draft_grade @draft_grade end |
#draft_rubric_grades ⇒ Hash<String,Google::Apis::ClassroomV1::RubricGrade>
Pending rubric grades based on the rubric's criteria. This map is empty if
there is no rubric attached to this course work or if a rubric is attached,
but no grades have been set on any criteria. Entries are only populated for
grades that have been set. Key: The rubric's criterion ID. Read-only.
Corresponds to the JSON property draftRubricGrades
2739 2740 2741 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2739 def draft_rubric_grades @draft_rubric_grades end |
#id ⇒ String
Classroom-assigned Identifier for the student submission. This is unique among
submissions for the relevant course work. Read-only.
Corresponds to the JSON property id
2745 2746 2747 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2745 def id @id end |
#late ⇒ Boolean Also known as: late?
Whether this submission is late. Read-only.
Corresponds to the JSON property late
2750 2751 2752 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2750 def late @late end |
#multiple_choice_submission ⇒ Google::Apis::ClassroomV1::MultipleChoiceSubmission
Student work for a multiple-choice question.
Corresponds to the JSON property multipleChoiceSubmission
2756 2757 2758 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2756 def multiple_choice_submission @multiple_choice_submission end |
#short_answer_submission ⇒ Google::Apis::ClassroomV1::ShortAnswerSubmission
Student work for a short answer question.
Corresponds to the JSON property shortAnswerSubmission
2761 2762 2763 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2761 def short_answer_submission @short_answer_submission end |
#state ⇒ String
State of this submission. Read-only.
Corresponds to the JSON property state
2766 2767 2768 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2766 def state @state end |
#submission_history ⇒ Array<Google::Apis::ClassroomV1::SubmissionHistory>
The history of the submission (includes state and grade histories). Read-only.
Corresponds to the JSON property submissionHistory
2771 2772 2773 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2771 def submission_history @submission_history end |
#update_time ⇒ String
Last update time of this submission. This may be unset if the student has not
accessed this item. Read-only.
Corresponds to the JSON property updateTime
2777 2778 2779 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2777 def update_time @update_time end |
#user_id ⇒ String
Identifier for the student that owns this submission. Read-only.
Corresponds to the JSON property userId
2782 2783 2784 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2782 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 2789 def update!(**args) @alternate_link = args[:alternate_link] if args.key?(:alternate_link) @assigned_grade = args[:assigned_grade] if args.key?(:assigned_grade) @assigned_rubric_grades = args[:assigned_rubric_grades] if args.key?(:assigned_rubric_grades) @assignment_submission = args[:assignment_submission] if args.key?(:assignment_submission) @associated_with_developer = args[:associated_with_developer] if args.key?(:associated_with_developer) @course_id = args[:course_id] if args.key?(:course_id) @course_work_id = args[:course_work_id] if args.key?(:course_work_id) @course_work_type = args[:course_work_type] if args.key?(:course_work_type) @creation_time = args[:creation_time] if args.key?(:creation_time) @draft_grade = args[:draft_grade] if args.key?(:draft_grade) @draft_rubric_grades = args[:draft_rubric_grades] if args.key?(:draft_rubric_grades) @id = args[:id] if args.key?(:id) @late = args[:late] if args.key?(:late) @multiple_choice_submission = args[:multiple_choice_submission] if args.key?(:multiple_choice_submission) @short_answer_submission = args[:short_answer_submission] if args.key?(:short_answer_submission) @state = args[:state] if args.key?(:state) @submission_history = args[:submission_history] if args.key?(:submission_history) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |