Class: Google::Apis::ClassroomV1::Topic
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::Topic
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
Topic created by a teacher for the course
Instance Attribute Summary collapse
-
#course_id ⇒ String
Identifier of the course.
-
#name ⇒ String
The name of the topic, generated by the user.
-
#topic_id ⇒ String
Unique identifier for the topic.
-
#update_time ⇒ String
The time the topic was last updated by the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Topic
constructor
A new instance of Topic.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Topic
Returns a new instance of Topic.
3079 3080 3081 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#course_id ⇒ String
Identifier of the course. Read-only.
Corresponds to the JSON property courseId
3059 3060 3061 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3059 def course_id @course_id end |
#name ⇒ String
The name of the topic, generated by the user. Leading and trailing whitespaces,
if any, are trimmed. Also, multiple consecutive whitespaces are collapsed
into one inside the name. The result must be a non-empty string. Topic names
are case sensitive, and must be no longer than 100 characters.
Corresponds to the JSON property name
3067 3068 3069 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3067 def name @name end |
#topic_id ⇒ String
Unique identifier for the topic. Read-only.
Corresponds to the JSON property topicId
3072 3073 3074 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3072 def topic_id @topic_id end |
#update_time ⇒ String
The time the topic was last updated by the system. Read-only.
Corresponds to the JSON property updateTime
3077 3078 3079 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3077 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3084 3085 3086 3087 3088 3089 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3084 def update!(**args) @course_id = args[:course_id] if args.key?(:course_id) @name = args[:name] if args.key?(:name) @topic_id = args[:topic_id] if args.key?(:topic_id) @update_time = args[:update_time] if args.key?(:update_time) end |