Class: Google::Apis::ClassroomV1::Topic

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb

Overview

Topic created by a teacher for the course

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Topic

Returns a new instance of Topic.



2957
2958
2959
# File 'lib/google/apis/classroom_v1/classes.rb', line 2957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#course_idString

Identifier of the course. Read-only. Corresponds to the JSON property courseId

Returns:

  • (String)


2937
2938
2939
# File 'lib/google/apis/classroom_v1/classes.rb', line 2937

def course_id
  @course_id
end

#nameString

The name of the topic, generated by the user. Leading and trailing whitespaces, if any, are trimmed. Also, multiple consecutive whitespaces are collapsed into one inside the name. The result must be a non-empty string. Topic names are case sensitive, and must be no longer than 100 characters. Corresponds to the JSON property name

Returns:

  • (String)


2945
2946
2947
# File 'lib/google/apis/classroom_v1/classes.rb', line 2945

def name
  @name
end

#topic_idString

Unique identifier for the topic. Read-only. Corresponds to the JSON property topicId

Returns:

  • (String)


2950
2951
2952
# File 'lib/google/apis/classroom_v1/classes.rb', line 2950

def topic_id
  @topic_id
end

#update_timeString

The time the topic was last updated by the system. Read-only. Corresponds to the JSON property updateTime

Returns:

  • (String)


2955
2956
2957
# File 'lib/google/apis/classroom_v1/classes.rb', line 2955

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2962
2963
2964
2965
2966
2967
# File 'lib/google/apis/classroom_v1/classes.rb', line 2962

def update!(**args)
  @course_id = args[:course_id] if args.key?(:course_id)
  @name = args[:name] if args.key?(:name)
  @topic_id = args[:topic_id] if args.key?(:topic_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end