Class: Google::Apis::ClassroomV1::YouTubeVideo
- Inherits:
-
Object
- Object
- Google::Apis::ClassroomV1::YouTubeVideo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/classroom_v1/classes.rb,
lib/google/apis/classroom_v1/representations.rb,
lib/google/apis/classroom_v1/representations.rb
Overview
YouTube video item.
Instance Attribute Summary collapse
-
#alternate_link ⇒ String
URL that can be used to view the YouTube video.
-
#id ⇒ String
YouTube API resource ID.
-
#thumbnail_url ⇒ String
URL of a thumbnail image of the YouTube video.
-
#title ⇒ String
Title of the YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YouTubeVideo
constructor
A new instance of YouTubeVideo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YouTubeVideo
Returns a new instance of YouTubeVideo.
3186 3187 3188 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_link ⇒ String
URL that can be used to view the YouTube video. Read-only.
Corresponds to the JSON property alternateLink
3169 3170 3171 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3169 def alternate_link @alternate_link end |
#id ⇒ String
YouTube API resource ID.
Corresponds to the JSON property id
3174 3175 3176 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3174 def id @id end |
#thumbnail_url ⇒ String
URL of a thumbnail image of the YouTube video. Read-only.
Corresponds to the JSON property thumbnailUrl
3179 3180 3181 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3179 def thumbnail_url @thumbnail_url end |
#title ⇒ String
Title of the YouTube video. Read-only.
Corresponds to the JSON property title
3184 3185 3186 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3184 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3191 3192 3193 3194 3195 3196 |
# File 'lib/google/apis/classroom_v1/classes.rb', line 3191 def update!(**args) @alternate_link = args[:alternate_link] if args.key?(:alternate_link) @id = args[:id] if args.key?(:id) @thumbnail_url = args[:thumbnail_url] if args.key?(:thumbnail_url) @title = args[:title] if args.key?(:title) end |